@@ -214,6 +214,7 @@ int _gnutls_proc_rsa_client_kx(gnutls_session session, opaque * data, size_t _da
 	int ret, dsize;
 	GNUTLS_MPI *params;
 	int params_len;
+	int randomize_key = 0;
 	ssize_t data_size = _data_size;
 
 	if (gnutls_protocol_get_version(session) == GNUTLS_SSL3) {
@@ -242,33 +243,47 @@ int _gnutls_proc_rsa_client_kx(gnutls_session session, opaque * data, size_t _da
 		params_len, 2);	/* btype==2 */
 
 	if (ret < 0 || plaintext.size != TLS_MASTER_SIZE) {
-		/* in case decryption fails then don't inform
+		/* In case decryption fails then don't inform
 		 * the peer. Just use a random key. (in order to avoid
 		 * attack against pkcs-1 formating).
 		 */
-		ret = 0;
 		gnutls_assert();
-
-		_gnutls_log("RSA_AUTH: Possible PKCS-1 format attack\n");
-
-		RANDOMIZE_KEY(session->key->key,
-			      gnutls_secure_malloc, GNUTLS_WEAK_RANDOM);
+		_gnutls_x509_log("auth_rsa: Possible PKCS #1 format attack\n");
+		randomize_key = 1;
 	} else {
-		ret = 0;
-		if (session->internals.rsa_pms_check==0)
-			if (_gnutls_get_adv_version_major(session) !=
-			    plaintext.data[0]
-			    || _gnutls_get_adv_version_minor(session) !=
-			    plaintext.data[1]) {
-				gnutls_assert();
-				ret = GNUTLS_E_DECRYPTION_FAILED;
-			}
+		/* If the secret was properly formatted, then
+		 * check the version number.
+		 */
+		if (_gnutls_get_adv_version_major(session) != plaintext.data[0]
+		    || _gnutls_get_adv_version_minor(session) != plaintext.data[1]) 
+		{
+		    	/* No error is returned here, if the version number check
+		    	 * fails. We proceed normally.
+		    	 * That is to defend against the attack described in the paper
+		    	 * "Attacking RSA-based sessions in SSL/TLS" by Vlastimil Klima,
+		    	 * Ondej Pokorny and Tomas Rosa.
+		    	 */
+			gnutls_assert();
+			_gnutls_x509_log("auth_rsa: Possible PKCS #1 version check format attack\n");
+		}
+	}
 
+	if (randomize_key != 0) {
+		RANDOMIZE_KEY(session->key->key,
+			      gnutls_malloc, GNUTLS_STRONG_RANDOM);
+
+	} else {
 		session->key->key.data = plaintext.data;
 		session->key->key.size = plaintext.size;
 	}
 
-	return ret;
+	/* This is here to avoid the version check attack
+	 * discussed above.
+	 */
+	session->key->key.data[0] = _gnutls_get_adv_version_major(session);
+	session->key->key.data[1] = _gnutls_get_adv_version_minor(session);
+
+	return 0;
 }
 
 
