@@ -363,7 +363,7 @@ void print_list(void)
 	printf(" RIJNDAEL-128-CBC");
 	printf(", TWOFISH-128-CBC");
 	printf(", 3DES-CBC");
-	printf(", ARCFOUR\n");
+	printf(", ARCFOUR");
 	printf(", ARCFOUR-40\n");
 
 	printf("MACs:");
