@@ -554,6 +554,7 @@ int main(int argc, char **argv)
       if ((ret = gnutls_certificate_set_x509_trust_file
 	   (cert_cred, x509_cafile, x509ctype)) < 0) {
 	 fprintf(stderr, "Error reading '%s'\n", x509_cafile);
+	 GERR( ret, "X509 trust file");
 	 exit(1);
       } else {
 	 printf("Processed %d CA certificate(s).\n", ret);
@@ -566,6 +567,7 @@ int main(int argc, char **argv)
 						      pgp_keyring);
       if (ret < 0) {
 	 fprintf(stderr, "Error setting the OpenPGP keyring file\n");
+	 GERR( ret, "Openpgp keyring");
       }
    }
 
@@ -573,6 +575,7 @@ int main(int argc, char **argv)
       ret = gnutls_certificate_set_openpgp_trustdb(cert_cred, pgp_trustdb);
       if (ret < 0) {
 	 fprintf(stderr, "Error setting the OpenPGP trustdb file\n");
+	 GERR( ret, "Openpgp trustdb");
       }
    }
 
@@ -580,16 +583,18 @@ int main(int argc, char **argv)
       if ((ret = gnutls_certificate_set_openpgp_key_file
 	   (cert_cred, pgp_certfile, pgp_keyfile)) < 0) {
 	 fprintf(stderr,
-		 "Error[%d] while reading the OpenPGP key pair ('%s', '%s')\n",
-		 ret, pgp_certfile, pgp_keyfile);
+		 "Error while reading the OpenPGP key pair ('%s', '%s')\n",
+		  pgp_certfile, pgp_keyfile);
+	 GERR( ret, "Openpgp key");
       }
 
    if (x509_certfile != NULL)
-      if (gnutls_certificate_set_x509_key_file
-	  (cert_cred, x509_certfile, x509_keyfile, x509ctype) < 0) {
+      if ((ret=gnutls_certificate_set_x509_key_file
+	  (cert_cred, x509_certfile, x509_keyfile, x509ctype)) < 0) {
 	 fprintf(stderr,
 		 "Error reading '%s' or '%s'\n", x509_certfile,
 		 x509_keyfile);
+	 GERR( ret, "X509 key");
 	 exit(1);
       }
 
